@@ -120,9 +120,9 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
         # prompt_date = prompt_time.date()
 
         if df_logs_combined.shape[0] == 0:
-            battery_level = np.nan
-            charging_status = np.nan
-            closest_time = np.nan
+            battery_level = "NF"
+            charging_status = "NF"
+            closest_time = "NF"
         else:
             subset_time_list = list(df_logs_combined["Local_Timestamp"])
 
@@ -135,8 +135,8 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
                 charging_status = list(df_logs_combined[df_logs_combined['Local_Timestamp'] == closest_time][
                                            "isCharging"])[0]
             else:
-                battery_level = np.nan
-                charging_status = np.nan
+                battery_level = "NF"
+                charging_status = "NF"
 
 
         matched_time_list.append(closest_time)
