@@ -122,7 +122,7 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
             df = pd.concat([df, mims_summary_df[col].rename("mims_summary_" + min_before + "min")], axis=1)
             df = pd.concat([df, readings_df[col].rename("num_readings_" + min_before + "min")], axis=1)
             df = pd.concat([df, start_time_df[col].rename("start_time_" + min_before + "min")], axis=1)
-        except:
+        except TypeError:
             print(df)
             print(mims_summary_df[col].rename("mims_summary_" + min_before + "min"))
             raise Exception("^^^^^^^^^^^^^^^^$$$$$$$$$$$" + df + "\n" + mims_summary_df[col].rename("mims_summary_" + min_before + "min"))
